import Flutter
import UIKit
import ZendeskSDK
import ZendeskCoreSDK


public class SwiftFlutterZenDeskPlugin: NSObject, FlutterPlugin {
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "flutter_zendesk", binaryMessenger: registrar.messenger())
        let instance = SwiftFlutterZenDeskPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        if(call.method.elementsEqual("initiate")){
            
            let args = call.arguments as? NSDictionary
            
            let appId = args!["appId"]as? String
            let clientId  = args!["clientId"]as? String
            let url = args!["url"]as? String
            
            Zendesk.initialize(appId: appId!,
                               clientId: clientId!,
                               zendeskUrl: url!)
            Support.initialize(withZendesk: Zendesk.instance)
            
            let ident = Identity.createAnonymous()
            Zendesk.instance?.setIdentity(ident)
            
            //Create a configuration object
            let config = RequestUiConfiguration()
            config.subject = "Testing the SDK"
            config.tags = ["ios", "testing"]
            //Present the SDK
            let requestScreen = RequestUi.buildRequestUi(with: [config])
            if let navigationController = UIApplication.shared.keyWindow?.rootViewController as? UINavigationController {
                navigationController.pushViewController(requestScreen, animated: true)
            }
            
            
            let storyboard : UIStoryboard? = UIStoryboard.init(name: "Main", bundle: nil);
            let window: UIWindow = ((UIApplication.shared.delegate?.window)!)!
            
            let objVC: UIViewController? = storyboard!.instantiateViewController(withIdentifier: "FlutterViewController")
            let aObjNavi = UINavigationController(rootViewController: objVC!)
            window.rootViewController = aObjNavi
            Theme.currentTheme.primaryColor = UIColor.black
            aObjNavi.present(requestScreen, animated: true)
        }
    }
}
